<?php

/**
 * @file smartqueue_users_handler_field_privacy.inc
 * Provides a handler class for displaying the privacy field of a subqueue.
 */

define('SMARTQUEUE_USERS_VIEWS_FILTER_PRIVACY_PUBLIC', 0x00);
define('SMARTQUEUE_USERS_VIEWS_FILTER_PRIVACY_PRIVATE', 0x01);

define('SMARTQUEUE_USERS_VIEWS_FILTER_PRIVACY_ALL', 0x00);
define('SMARTQUEUE_USERS_VIEWS_FILTER_PRIVACY_NONE', 0x01);

class smartqueue_users_handler_filter_privacy extends views_handler_filter {
  
/**
   * Construct a new field handler.
   * @see [modules]/views/handlers/views_handler_filter#construct()
   */
  function construct() {
    parent::construct();
    
    // Attach the additional fields from the definition
    $this->additional_fields = $this->definition['additional fields'];
  }
  
  function option_definition() {
    $options['filter_privacy_smartqueue_per_users'] = array(
      'default' => SMARTQUEUE_USERS_VIEWS_FILTER_PRIVACY_PUBLIC,
    );
    $options['filter_privacy_other_nodequeues'] = array(
      'default' => SMARTQUEUE_USERS_VIEWS_FILTER_PRIVACY_ALL,
    );
    
    return $options;
  }
  
  function options_form(&$form, &$form_state) {
    $smartqueue_users_options = array(
      SMARTQUEUE_USERS_VIEWS_FILTER_PRIVACY_PUBLIC => t('Public'),
      SMARTQUEUE_USERS_VIEWS_FILTER_PRIVACY_PRIVATE => t('Private'),
    );
    
    $other_nodequeues_options = array(
      SMARTQUEUE_USERS_VIEWS_FILTER_PRIVACY_ALL => t('All'),
      SMARTQUEUE_USERS_VIEWS_FILTER_PRIVACY_NONE => t('None'),
    );
    
    $form['filter_privacy_smartqueue_per_users'] = array(
      '#type' => 'radios',
      '#title' => t('Smartqueue per User subqueues'),
      '#description' => t('Out of all Smartqueue per User subqueues results, which subqueues to display?'),
      '#options' => $smartqueue_users_options,
      '#default_value' => $this->options['filter_privacy_smartqueue_per_users'],
    );
    
    $form['filter_privacy_other_nodequeues'] = array(
      '#type' => 'radios',
      '#title' => t('Other subqueues'),
      '#description' => t('Out of all subqueues results that are not Smartqueue per User subqueues, which subqueues to display?'),
      '#options' => $other_nodequeues_options,
      '#default_value' => $this->options['filter_privacy_other_nodequeues'],
    );
  }
  
  function query() {
    $this->ensure_my_table();
    
    $this->query->add_table('nodequeue_queue', $this->relationship); // TODO - Why does this crash? we need nodequeue_queue for the owner and qid
  }
  
}
